@@ -8,7 +8,7 @@
 #' ch_currency(10)
 #' ch_currency(500)
 ch_currency <- function(n = 1) {
-  assert(n, c('integer', 'numeric'))
+  assert(n, c("integer", "numeric"))
   if (n == 1) {
     CurrencyProvider$new()$render()
   } else {
