@@ -10,7 +10,7 @@
 #' for data types that have locale support, See each data provider for
 #' details.
 #' @section Allowed column names:
-#' 
+#'
 #' - name (default included)
 #' - job (default included)
 #' - phone_number (default included)
@@ -18,15 +18,15 @@
 #' - color_name
 #' - rgb_color
 #' - rgb_css_color
-#' 
+#'
 #' @examples
 #' ch_generate()
 #' ch_generate(n = 1)
 #' ch_generate(n = 100)
 #'
-#' ch_generate('job')
-#' ch_generate('job', 'name')
-#' ch_generate('job', 'color_name')
+#' ch_generate("job")
+#' ch_generate("job", "name")
+#' ch_generate("job", "color_name")
 #'
 #' # locale
 #' ch_generate(locale = "en_US")
@@ -35,13 +35,14 @@
 ch_generate <- function(..., n = 10, locale = NULL) {
   choices <- unlist(list(...))
   if (length(choices) == 0) choices <- c("name", "job", "phone_number")
-  #stopifnot(inherits(choices, "character"))
+  # stopifnot(inherits(choices, "character"))
   assert(choices, "character")
 
   if (!all(choices %in% all_choices)) {
     stop("column name must be selected from the following:\n  ",
-         paste0(all_choices, collapse = "\n  "),
-         call. = FALSE)
+      paste0(all_choices, collapse = "\n  "),
+      call. = FALSE
+    )
   }
   cols <- stats::setNames(
     lapply(choices, function(z) {
@@ -57,5 +58,7 @@ ch_generate <- function(..., n = 10, locale = NULL) {
   tibble::as_tibble(cols)
 }
 
-all_choices <- c("name", "job", "phone_number", "currency",
-                 "color_name", "rgb_color", "rgb_css_color")
+all_choices <- c(
+  "name", "job", "phone_number", "currency",
+  "color_name", "rgb_color", "rgb_css_color"
+)
