@@ -9,7 +9,7 @@
 #' ch_missing(letters, 10)
 #' ch_missing(letters, 20)
 ch_missing <- function(x, n = 1) {
-  assert(n, c('integer', 'numeric'))
+  assert(n, c("integer", "numeric"))
   if (n == 1) {
     MissingDataProvider$new()$make_missing(x)
   } else {
