@@ -1,30 +1,30 @@
 # modified from the python library faker:
 # https://github.com/joke2k/faker/blob/master/faker/providers/person/fr_CH/__init__.py
 
-person_formats_female_fr_ch = c(
-  '{{first_names_female}} {{last_names}}',
-  '{{first_names_female}} {{last_names}}',
-  '{{first_names_female}} {{last_names}}',
-  '{{first_names_female}} {{last_names}}',
-  '{{first_names_female}} {{last_names}}',
-  '{{first_names_female}} {{last_names}}',
-  '{{first_names_female}} {{last_names1}}-{{last_names2}}'
+person_formats_female_fr_ch <- c(
+  "{{first_names_female}} {{last_names}}",
+  "{{first_names_female}} {{last_names}}",
+  "{{first_names_female}} {{last_names}}",
+  "{{first_names_female}} {{last_names}}",
+  "{{first_names_female}} {{last_names}}",
+  "{{first_names_female}} {{last_names}}",
+  "{{first_names_female}} {{last_names1}}-{{last_names2}}"
 )
 
-person_formats_male_fr_ch = c(
-  '{{first_names_male}} {{last_names}}',
-  '{{first_names_male}} {{last_names}}',
-  '{{first_names_male}} {{last_names}}',
-  '{{first_names_male}} {{last_names}}',
-  '{{first_names_male}} {{last_names}}',
-  '{{first_names_male}} {{last_names}}',
-  '{{first_names_male}} {{last_names1}}-{{last_names2}}'
+person_formats_male_fr_ch <- c(
+  "{{first_names_male}} {{last_names}}",
+  "{{first_names_male}} {{last_names}}",
+  "{{first_names_male}} {{last_names}}",
+  "{{first_names_male}} {{last_names}}",
+  "{{first_names_male}} {{last_names}}",
+  "{{first_names_male}} {{last_names}}",
+  "{{first_names_male}} {{last_names1}}-{{last_names2}}"
 )
 
-person_formats_fr_ch = c(person_formats_male_fr_ch, person_formats_female_fr_ch)
+person_formats_fr_ch <- c(person_formats_male_fr_ch, person_formats_female_fr_ch)
 
 # source: http://www.bfs.admin.ch/bfs/portal/fr/index/news/publikationen.html?publicationID=6704
-person_first_names_male_fr_ch = c(
+person_first_names_male_fr_ch <- c(
   "Alain",
   "Albert",
   "Alexandre",
@@ -98,7 +98,7 @@ person_first_names_male_fr_ch = c(
   "Vincent"
 )
 
-person_first_names_female_fr_ch = c(
+person_first_names_female_fr_ch <- c(
   "Alice",
   "Alicia",
   "Ana",
@@ -178,10 +178,10 @@ person_first_names_female_fr_ch = c(
   "Zo\u00e9"
 )
 
-person_first_names_fr_ch = c(person_first_names_male_fr_ch, person_first_names_female_fr_ch)
+person_first_names_fr_ch <- c(person_first_names_male_fr_ch, person_first_names_female_fr_ch)
 
 # source = http://kunden.eye.ch/swissgen/rsr/index.html
-person_last_names_fr_ch = c(
+person_last_names_fr_ch <- c(
   "Aebi",
   "Aeby",
   "Alber",
